.. image:: https://travis-ci.org/Tomasito665/beatsearch.svg?branch=master
    :target: https://travis-ci.org/Tomasito665/beatsearch

Beatsearch
==========

Beatsearch is a Python library for feature extraction, distance computation and visualization of symbolic rhythms.

Documentation: https://tomasito665.github.io/beatsearch
